@@ -198,6 +198,7 @@ enum REGISTERCONNECTION_RETURN_VALUES {
 	OER_REGISTERCONNECTION_ERR_WRITE,
 	OER_REGISTERCONNECTION_ERR_HANDLESERVERDATA,
 	OER_REGISTERCONNECTION_ALREADY_REGISTERED,
+	OER_REGISTERCONNECTION_TIMEOUT,
 	OER_REGISTERCONNECTION_ERROR,
 	OER_REGISTERCONNECTION_EVERYTHING_OK
 };
@@ -243,6 +244,7 @@ enum OER_TIMED_PRIORITIES {
 	OER_TIMED_PRIORITY_CTCP,
 	OER_TIMED_PRIORITY_NOTICE,
 	OER_TIMED_PRIORITY_PRIVMSG,
+	OER_TIMED_PRIORITY_ADVERT,
 	OER_TIMED_PRIORITY_NORMAL,
 	OER_TIMED_PRIORITY_CHANNEL_HANDLING,
 	OER_TIMED_PRIORITY_CHANNEL_PROTECTION,
@@ -308,6 +310,7 @@ enum OER_FLAGS_TYPE {
 #define OER_SEEN_MAX 10
 #define OER_PERMBANS 25
 #define OER_LOGON_TIMEOUT 1800
+#define OER_REGISTERCONNECTION_TIMEOUT 600
 #define OER_BANVARS_AUTO_REJOIN 30
 #define OER_BANVARS_PART_REJOIN 600
 #define OER_BANVARS_PUBLIC_FLOOD 300
@@ -358,7 +361,7 @@ enum OER_FLAGS_TYPE {
 #define OER_SERVER_IS_STONED "stoned server"
 #define OER_INTERNAL_DYNAMIC_ADMIN "*INTDYN*"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-55, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-56, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -556,6 +559,7 @@ struct server {
 	time_t linkup;
         char password[TINYSTRINGLEN + 1];
 	time_t lastping;
+	time_t registerconnection_start;
 	struct server *prev;
 	struct server *next;
 };
@@ -620,6 +624,7 @@ struct state {
 	char realname[STRINGLEN + 1];
 	char flags[FLAGLEN + 1];
 	char prefix[MICROSTRINGLEN + 1];
+	char proxysetup[STRINGLEN + 1];
 	int customuser;
 	int vhost;
 	int use_altnick;
